summaryrefslogtreecommitdiffstats
path: root/libkdegames/kgame/dialogs/kgamedialog.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdegames/kgame/dialogs/kgamedialog.h')
-rw-r--r--libkdegames/kgame/dialogs/kgamedialog.h25
1 files changed, 13 insertions, 12 deletions
diff --git a/libkdegames/kgame/dialogs/kgamedialog.h b/libkdegames/kgame/dialogs/kgamedialog.h
index 709f71c6..cb731993 100644
--- a/libkdegames/kgame/dialogs/kgamedialog.h
+++ b/libkdegames/kgame/dialogs/kgamedialog.h
@@ -74,6 +74,7 @@ class KGameDialogPrivate;
class KDE_EXPORT KGameDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
enum ConfigOptions
@@ -94,11 +95,11 @@ public:
* @param owner The KPlayer object who is responsible for this
* dialog, aka "the local player"
* @param title The title of the dialog - see KDialog::setCaption
* @param parent The parent of the dialog
* @param modal Whether the dialog is modal or not
**/
KGameDialog(KGame* g, KPlayer* owner, const TQString& title,
- TQWidget* parent, bool modal = false);
+ TQWidget* tqparent, bool modal = false);
/**
* Create a KGameDialog with the standard configuration widgets. This
@@ -121,7 +122,7 @@ public:
* @param owner The KPlayer object who is responsible for this
* dialog, aka "the local player"
* @param title The title of the dialog - see KDialog::setCaption
* @param parent The parent of the dialog
* @param modal Whether the dialog is modal or not
* @param initConfigs whether the default KGameDialogConfig widgets
* shall be created using initDefaultDialog. Use false if you want
@@ -130,7 +131,7 @@ public:
* if initConfigs = false
**/
KGameDialog(KGame* g, KPlayer* owner, const TQString& title,
- TQWidget* parent, long initConfigs = AllConfig,
+ TQWidget* tqparent, long initConfigs = AllConfig,
int chatMsgId = 15432, bool modal = false);
virtual ~KGameDialog();
@@ -168,14 +169,14 @@ public:
virtual void submitToKGame();
/**
* Adds a KGameChat to the dialog. If no parent is specified the
* game page will be used.
* @param chat The chat widget
* @param parent The parent of the chat widget. This MUST be an
* already added config widget. Note that the game page will be used
- * if parent is 0.
+ * if tqparent is 0.
**/
- void addChatWidget(KGameDialogChatConfig* chat, TQVBox* parent = 0);
+ void addChatWidget(KGameDialogChatConfig* chat, TQVBox* tqparent = 0);
/**
* Add a connection list to the dialog. The list consists of a
@@ -186,10 +187,10 @@ public:
* This is another not-really-config-config-widget. It just displays the
* connections and lets you ban players.
* @param c The KGameDialogConnectionConfig object
* @param parent The parent of the widget. If 0 the networkConfig
* page is used.
**/
- void addConnectionList(KGameDialogConnectionConfig* c, TQVBox* parent = 0);
+ void addConnectionList(KGameDialogConnectionConfig* c, TQVBox* tqparent = 0);
/**
* Add a new page to the dialog. The page will contain you new config
@@ -222,12 +223,12 @@ public:
KGameDialogGeneralConfig* gameConfig() const;
/**
* Add a config widget to the specified parent. Usually you call
* addConfigPage for one widget and addConfigWidget for another to add
* it to the same page. Just use the returned page of
* addConfigPage.
**/
- void addConfigWidget(KGameDialogConfig* widget, TQWidget* parent);
+ void addConfigWidget(KGameDialogConfig* widget, TQWidget* tqparent);
/**
* Used to add the main network config widget in a new page. Use this to
@@ -94,11 +95,11 @@ public:
* dialog, aka "the local player"
* @param title The title of the dialog - see KDialog::setCaption
- * @param parent The parent of the dialog
+ * @param tqparent The tqparent of the dialog
* @param modal Whether the dialog is modal or not
**/
@@ -121,7 +122,7 @@ public:
* dialog, aka "the local player"
* @param title The title of the dialog - see KDialog::setCaption
- * @param parent The parent of the dialog
+ * @param tqparent The tqparent of the dialog
* @param modal Whether the dialog is modal or not
* @param initConfigs whether the default KGameDialogConfig widgets
@@ -168,14 +169,14 @@ public:
virtual void submitToKGame();
/**
- * Adds a KGameChat to the dialog. If no parent is specified the
+ * Adds a KGameChat to the dialog. If no tqparent is specified the
* game page will be used.
* @param chat The chat widget
@@ -168,14 +169,14 @@ public:
* game page will be used.
* @param chat The chat widget
- * @param parent The parent of the chat widget. This MUST be an
+ * @param tqparent The tqparent of the chat widget. This MUST be an
* already added config widget. Note that the game page will be used
@@ -186,10 +187,10 @@ public:
* connections and lets you ban players.
* @param c The KGameDialogConnectionConfig object
- * @param parent The parent of the widget. If 0 the networkConfig
+ * @param tqparent The tqparent of the widget. If 0 the networkConfig
* page is used.
**/
@@ -222,12 +223,12 @@ public:
KGameDialogGeneralConfig* gameConfig() const;
/**
- * Add a config widget to the specified parent. Usually you call
+ * Add a config widget to the specified tqparent. Usually you call
* addConfigPage for one widget and addConfigWidget for another to add
* it to the same page. Just use the returned page of